emailuis/uicomponents/inc/fstreevisualizerbase.h
branchRCL_3
changeset 80 726fba06891a
parent 73 c8382f7b54ef
--- a/emailuis/uicomponents/inc/fstreevisualizerbase.h	Wed Sep 15 11:52:37 2010 +0300
+++ b/emailuis/uicomponents/inc/fstreevisualizerbase.h	Wed Oct 13 14:11:15 2010 +0300
@@ -843,27 +843,15 @@
     /**
      * Sets icon for a mark sign.
      *
      * @param aMarkOnIcon Icon to mark items.
      */
-    virtual void SetMarkOnIcon( CAlfTexture& aMarkOnIcon );
+    virtual void SetMarkIcon( CAlfTexture& aMarkIcon );
 
     /**
-     * Sets icon for a mark sign.
-     *
-     * @param aMarkOffIcon Icon to unmark items.
+     * Returns icon used to mark items.
      */
-    virtual void SetMarkOffIcon( CAlfTexture& aMarkOffIcon );
-
-    /**
-     * Returns icon used to identify marked items.
-     */
-    virtual CAlfTexture* MarkOnIcon( );
-
-    /**
-     * Returns icon used to identify unmarked items.
-     */
-    virtual CAlfTexture* MarkOffIcon( );    
-    
+    virtual CAlfTexture* MarkIcon( );
+
     /**
      * Checks if item is marked and return status
      * @param aItemId item id to be checked
@@ -936,14 +924,6 @@
     void SetFocusedL( const TBool aFocused );
 
     /**
-     * Sets marking mode on\off
-     * 
-     * @param ETrue if marking mode is set on
-     */
-
-    void SetMarkingModeL( const TBool aMarkingMode );
-
-    /**
      *
      * @param aTexture A custom texture for the selector.
      *                 The texture is used to create an image brush.
@@ -1029,7 +1009,9 @@
      *
      * @panic EFsListPanicInvalidItemID Item with specified ID is not found.
      */
+    // <cmail>
     virtual void SetFocusedItemL( const TFsTreeItemId aItem, TBool aCheckFocus = ETrue );
+    // </cmail>
 
     /**
     * Gets item vertical position in the list
@@ -1060,7 +1042,9 @@
      *
      * @param aItemId Id of an item that will be displayed as first.
      */
+    // <cmail>
     virtual void SetFirstVisibleItemL( const TFsTreeItemId aItemId );
+    // </cmail>
 
     /**
      * Get an id of the first visible item.
@@ -1316,11 +1300,6 @@
      */
     virtual TBool IsItemsAlwaysExtended ( );
 
-    /*
-     * The function returns ETrue if marking mode is on
-     */
-    virtual TBool IsMarkingMode ( );    
-    
     /**
      * The function sets a text for empty list's view.
      * The function does not refresh the view automatically.
@@ -2192,13 +2171,8 @@
     /**
      * Icon used to mark items.
      */
-    CAlfTexture* iMarkOnIcon;
-
-    /**
-     * Icon used to unmark items.
-     */
-    CAlfTexture* iMarkOffIcon;    
-    
+    CAlfTexture* iMarkIcon;
+
     /**
      * Icon indicating that item has menu.
      */
@@ -2396,12 +2370,7 @@
          * This flag is checked when trying to focus item. Focus is ignored 
          * if list is being panned. 
          */        
-        EListPanning,
-		
-        /**
-         * Informs if marking mode is on
-         */
-        EMarkingMode
+        EListPanning
     };
 
     // Flags
@@ -843,27 +843,15 @@
      * Sets icon for a mark sign.
      *
-     * @param aMarkOnIcon Icon to mark items.
+     * @param aMarkIcon Icon to mark items.
      */